@@ -26,11 +26,11 @@ rm -f ./tests/data-sources-list-test/Ubuntu.mirrors
 
 # update demotions
 # echo "Running demotions"
-(cd utils && ./demotions.py hirsute impish > demoted.cfg)
+(cd utils && ./demotions.py impish jammy > demoted.cfg)
 
 # when this gets enabled, make sure to add symlink in DistUpgrade
 # echo "Running lts demotions"
-(cd utils && ./demotions.py focal impish > demoted.cfg.focal)
+(cd utils && ./demotions.py focal jammy > demoted.cfg.focal)
 
 # update apt_btrfs_snapshot.py copy, this needs an installed
 # apt-btrfs-snapshot on the build machine
