@@ -795,7 +795,7 @@ class TestSnapQuirks(unittest.TestCase):
         self.maxDiff = None
         self.assertDictEqual(
             q._snap_list,
-            {'core18': {
+            {'core20': {
                 'channel': 'stable',
                 'command': 'install',
                 'deb': None, 'snap-id': '1234'},
@@ -820,6 +820,35 @@ class TestSnapQuirks(unittest.TestCase):
                 'deb': 'gnome-software',
                 'snap-id': '1234'}})
 
+    def test_is_deb2snap_metapkg_installed(self):
+        # Prepare the state for testing
+        controller = mock.Mock()
+        config = mock.Mock()
+        q = DistUpgradeQuirks(controller, config)
+        q._from_version = "19.04"
+        q._to_version = "19.10"
+        controller.cache = {
+            'ubuntu-desktop':
+                make_mock_pkg(
+                    name="ubuntu-desktop",
+                    is_installed=True)
+        }
+
+        testdata = [
+            # (input, expected output)
+            ({}, False),
+            ({'metapkg': None}, False),
+            ({'metapkg': 'ubuntu-desktop'}, True),
+            ({'metapkg': 'kubuntu-desktop'}, False),
+            ({'metapkg': ['kubuntu-desktop', 'ubuntu-desktop']}, True),
+            ({'metapkg': ['kubuntu-desktop', 'lubuntu-desktop']}, False),
+        ]
+
+        for data in testdata:
+            self.assertEqual(q._is_deb2snap_metapkg_installed(data[0]),
+                             data[1],
+                             'Expected {1} for input {0}'.format(*data))
+
     @mock.patch("DistUpgrade.DistUpgradeQuirks.get_arch")
     @mock.patch("urllib.request.urlopen")
     def test_calculate_snap_size_requirements(self, urlopen, arch):
@@ -929,6 +958,37 @@ class TestSnapQuirks(unittest.TestCase):
         # actual deb packages that will have to be removed during the upgrade
         self.assertEqual(controller.forced_obsoletes.append.call_count, 3)
 
+    @mock.patch("builtins.open", new_callable=mock.mock_open,
+                read_data="""\
+processor       : 0
+cpu             : POWER8 (raw), altivec supported
+clock           : 3491.000000MHz
+revision        : 2.0 (pvr 004d 0200)
+
+processor       : 1
+cpu             : POWER8 (raw), altivec supported
+clock           : 3491.000000MHz
+revision        : 2.0 (pvr 004d 0200)
+
+timebase        : 512000000
+platform        : PowerNV
+model           : 8001-22C
+machine         : PowerNV 8001-22C
+firmware        : OPAL
+MMU             : Hash
+""")
+    @mock.patch("DistUpgrade.DistUpgradeQuirks.get_arch",
+                return_value="ppc64el")
+    def test_power8_fail(self, arch, mock_file):
+        controller = mock.Mock()
+        config = mock.Mock()
+        q = DistUpgradeQuirks(controller, config)
+
+        q._test_and_fail_on_power8()
+        self.assertTrue(len(controller.abort.mock_calls))
+
+        mock_file.assert_called_with("/proc/cpuinfo")
+
 
 if __name__ == "__main__":
     import logging
